@@ -8,6 +8,6 @@ from PyQt4.QtGui import QApplication
 app = QApplication(sys.argv)
 app.setOrganizationName("Stuart Howarth")
 app.setOrganizationDomain("marxianthecoder.blogspot.com")
-app.setApplicationName("cuteTube")
+app.setApplicationName("FMRadio")
 cuteTube = homewindow.HomeWindow()
 app.exec_()
