@@ -19,6 +19,8 @@ class YouTubeAPISettings():
     userDict = {}
     defaultUser = ""
     raiseNoAccountFoundDialog = True
+    categoryFilter = "All"
+    locationFilter = "All"
 
 class VideoPlaybackSettings():
     """
