@@ -54,6 +54,8 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         self.connect(self.actionEditVideo, SIGNAL("triggered()"), self.editVideo)
         self.connect(self.moreButton, SIGNAL("pressed()"), self.changeButtonStyleSheet)
         self.connect(self.moreButton, SIGNAL("released()"), self.changeButtonStyleSheet)
+        self.orientationChanged()
+        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged) 
         
     def changeButtonStyleSheet(self):
         """
@@ -66,6 +68,17 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
             self.moreButton.setStyleSheet("font-size: 18px; border-radius: 4px; background-color: rgb(120, 120, 120, 150)")
         else:
             self.moreButton.setStyleSheet("font-size: 18px; border-radius: 4px; background-color: rgb(0, 0, 0, 100)")
+            
+    def orientationChanged(self):
+        """
+        Sets the position of the 'more' button according to 
+        the screen orientation.
+        """
+        screenGeometry = QApplication.desktop().screenGeometry()
+        if screenGeometry.height() > screenGeometry.width():
+            self.moreButton.setGeometry(QRect(402, 670, 85, 80))
+        else:
+            self.moreButton.setGeometry(QRect(722, 352, 85, 80))
 
     def filterList(self, event):
         """
@@ -174,10 +187,21 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
         
     def getMoreResults(self, scrollBarPos):
         """
-        Retrieves further results.
+        Shows the 'more' button to enable the user to 
+        get more results.
         """
-        if self.yt.isFinished() and self.yt.moreResults and scrollBarPos > (self.yt.results - 15) * 79:
-            self.loadData()
+        if self.yt.isFinished() and self.yt.moreResults and scrollBarPos > (self.yt.results - 10) * 94:
+            self.moreButton.setVisible(True)
+        else:
+            self.moreButton.setVisible(False)
+            
+    @pyqtSignature("")
+    def on_moreButton_clicked(self):
+        """
+        Appends more results to the list.
+        """
+        self.loadData()
+        self.moreButton.setVisible(False)
 
     def reloadData(self):
         """
@@ -501,7 +525,6 @@ class SearchResultsWindow(CutetubeWindows):
         searchTerms = self.searchString.replace(" ", "+")
         if username == None:
             self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?q=%s&safeSearch=none&orderby=%s" % (searchTerms, searchOrder)
-            self.actionSearch.setVisible(True)
         else:
             self.videoFeed = "http://gdata.youtube.com/feeds/api/videos?author=%s&q=%s&safeSearch=none&orderby=%s" % (username, searchTerms, searchOrder)
         self.yt = youtubeservice.YouTubeVideoFeed(self, self.videoFeed)
@@ -659,6 +682,7 @@ class FavouritesWindow(CutetubeWindows):
         self.actionAddToPlaylist.setVisible(True)
         self.actionRemoveFromFavourites.setVisible(True)
         self.actionPencil.setVisible(True)
+        self.actionPencilFavourites.setVisible(False)
         self.connect(self.actionRemoveFromFavourites, SIGNAL("triggered()"), self.removeFromFavourites)        
         self.pencilList = []
         self.show()
