@@ -111,7 +111,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         """
         CutetubeLog.logInfo("Restoring settings")
         try:
-            settings = QSettings()
+            settings = QSettings("Stuart Howarth", "cuteTube")
             GeneralSettings.autoOrientation = settings.value("autoOrientation", True).toBool()
             YouTubeAPISettings.userDict = settings.value("userDict",  {}).toPyObject()
             YouTubeAPISettings.defaultUser = settings.value("defaultUser",  "").toString()
@@ -143,7 +143,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         """
         try:
             CutetubeLog.logInfo("Saving settings")
-            settings = QSettings()
+            settings = QSettings("Stuart Howarth", "cuteTube")
             autoOrientation = QVariant(GeneralSettings.autoOrientation)
             userDict = QVariant(YouTubeAPISettings.userDict)
             defaultUser = QVariant(YouTubeAPISettings.defaultUser)
