@@ -596,7 +596,7 @@ class YouTubeVideoDownloader(object):
         """
         for task in taskList:
             videoId = unicode(task, "utf-8")
-            video = YouTubeDataService.getVideoEntry(videoId)
+            video = YouTubeDataService.getVideoEntry(videoId, apiVersion = 2)
             YouTubeVideoDownloader.addTask(video)
     
     @staticmethod
